
// According to RFC 3986, only characters from a set of reserved and a set
// of unreserved characters are allowed in a URL:
var unreserved = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz-_.~";
var reserved = "!*'();:@&=+$,/?%#[]";
var allowed = unreserved + reserved;
var hexchars = "0123456789ABCDEFabcdef";

// --------------------------------- Encoding URL -------------------------------

// This function returns a percent sign followed by two hexadecimal digits.
// Input is a decimal value not greater than 255.
function gethex(decimal) {
  return "%" + hexchars.charAt(decimal >> 4) + hexchars.charAt(decimal & 0xF);
  }

function encode(vloc) {
  // Some variables:
  var decoded = vloc;
  var encoded = "";

    for (var i = 0; i < decoded.length; i++ ) {
      var ch = decoded.charAt(i);
      // Check if character is an unreserved character:
      if (unreserved.indexOf(ch) != -1) {
        encoded = encoded + ch;
      } else {

        var charcode = decoded.charCodeAt(i);

        // Position 0 - 127 is equal to percent-encoding with an ASCII character encoding:
        if (charcode < 128) {
          encoded = encoded + gethex(charcode);
        }

        // Position 128 - 2047: two bytes for UTF-8 character encoding.
        if (charcode > 127 && charcode < 2048) {
          // First UTF byte: Mask the first five bits of charcode with binary 110X.XXXX:
          encoded = encoded + gethex((charcode >> 6) | 0xC0);
          // Second UTF byte: Get last six bits of charcode and mask them with binary 10XX.XXXX:
          encoded = encoded + gethex((charcode & 0x3F) | 0x80);
        }

        // Position 2048 - 65535: three bytes for UTF-8 character encoding.
        if (charcode > 2047 && charcode < 65536) {
          // First UTF byte: Mask the first four bits of charcode with binary 1110.XXXX:
          encoded = encoded + gethex((charcode >> 12) | 0xE0);
          // Second UTF byte: Get the next six bits of charcode and mask them binary 10XX.XXXX:
          encoded = encoded + gethex(((charcode >> 6) & 0x3F) | 0x80);
          // Third UTF byte: Get the last six bits of charcode and mask them binary 10XX.XXXX:
          encoded = encoded + gethex((charcode & 0x3F) | 0x80);
        }

        // Position 65536 - : four bytes for UTF-8 character encoding.
        if (charcode > 65535) {
          // First UTF byte: Mask the first three bits of charcode with binary 1111.0XXX:
          encoded = encoded + gethex((charcode >> 18) | 0xF0);
          // Second UTF byte: Get the next six bits of charcode and mask them binary 10XX.XXXX:
          encoded = encoded + gethex(((charcode >> 12) & 0x3F) | 0x80);
          // Third UTF byte: Get the last six bits of charcode and mask them binary 10XX.XXXX:
          encoded = encoded + gethex(((charcode >> 6) & 0x3F) | 0x80);
          // Fourth UTF byte: Get the last six bits of charcode and mask them binary 10XX.XXXX:
          encoded = encoded + gethex((charcode & 0x3F) | 0x80);
        }

      }

    }  // end of for ...

    return encoded;
	
  };

function HTMLentities(texte) {

texte = texte.replace(/"/g,'&quot;'); // 34 22
texte = texte.replace(/&/g,'&amp;'); // 38 26
texte = texte.replace(/\'/g,'&#39;'); // 39 27
texte = texte.replace(/</g,'&lt;'); // 60 3C
texte = texte.replace(/>/g,'&gt;'); // 62 3E
texte = texte.replace(/\^/g,'&circ;'); // 94 5E
texte = texte.replace(/'/g,'&lsquo;'); // 145 91
texte = texte.replace(/'/g,'&rsquo;'); // 146 92
texte = texte.replace(/"/g,'&ldquo;'); // 147 93
texte = texte.replace(/"/g,'&rdquo;'); // 148 94
texte = texte.replace(//g,'&bull;'); // 149 95
texte = texte.replace(//g,'&ndash;'); // 150 96
texte = texte.replace(//g,'&mdash;'); // 151 97
texte = texte.replace(//g,'&tilde;'); // 152 98
texte = texte.replace(//g,'&trade;'); // 153 99
texte = texte.replace(//g,'&scaron;'); // 154 9A
texte = texte.replace(//g,'&rsaquo;'); // 155 9B
texte = texte.replace(//g,'&oelig;'); // 156 9C
texte = texte.replace(//g,'&#357;'); // 157 9D
texte = texte.replace(//g,'&#382;'); // 158 9E
texte = texte.replace(//g,'&Yuml;'); // 159 9F
// texte = texte.replace(/ /g,'&nbsp;'); // 160 A0
texte = texte.replace(//g,'&iexcl;'); // 161 A1
texte = texte.replace(//g,'&cent;'); // 162 A2
texte = texte.replace(//g,'&pound;'); // 163 A3
//texte = texte.replace(/ /g,'&curren;'); // 164 A4
texte = texte.replace(//g,'&yen;'); // 165 A5
texte = texte.replace(//g,'&brvbar;'); // 166 A6
texte = texte.replace(//g,'&sect;'); // 167 A7
texte = texte.replace(//g,'&uml;'); // 168 A8
texte = texte.replace(//g,'&copy;'); // 169 A9
texte = texte.replace(//g,'&ordf;'); // 170 AA
texte = texte.replace(//g,'&laquo;'); // 171 AB
texte = texte.replace(//g,'&not;'); // 172 AC
texte = texte.replace(//g,'&shy;'); // 173 AD
texte = texte.replace(//g,'&reg;'); // 174 AE
texte = texte.replace(//g,'&macr;'); // 175 AF
texte = texte.replace(//g,'&deg;'); // 176 B0
texte = texte.replace(//g,'&plusmn;'); // 177 B1
texte = texte.replace(//g,'&sup2;'); // 178 B2
texte = texte.replace(//g,'&sup3;'); // 179 B3
texte = texte.replace(//g,'&acute;'); // 180 B4
texte = texte.replace(//g,'&micro;'); // 181 B5
texte = texte.replace(//g,'&para'); // 182 B6
texte = texte.replace(//g,'&middot;'); // 183 B7
texte = texte.replace(//g,'&cedil;'); // 184 B8
texte = texte.replace(//g,'&sup1;'); // 185 B9
texte = texte.replace(//g,'&ordm;'); // 186 BA
texte = texte.replace(//g,'&raquo;'); // 187 BB
texte = texte.replace(//g,'&frac14;'); // 188 BC
texte = texte.replace(//g,'&frac12;'); // 189 BD
texte = texte.replace(//g,'&frac34;'); // 190 BE
texte = texte.replace(//g,'&iquest;'); // 191 BF
texte = texte.replace(//g,'&Agrave;'); // 192 C0
texte = texte.replace(//g,'&Aacute;'); // 193 C1
texte = texte.replace(//g,'&Acirc;'); // 194 C2
texte = texte.replace(//g,'&Atilde;'); // 195 C3
texte = texte.replace(//g,'&Auml;'); // 196 C4
texte = texte.replace(//g,'&Aring;'); // 197 C5
texte = texte.replace(//g,'&AElig;'); // 198 C6
texte = texte.replace(//g,'&Ccedil;'); // 199 C7
texte = texte.replace(//g,'&Egrave;'); // 200 C8
texte = texte.replace(//g,'&Eacute;'); // 201 C9
texte = texte.replace(//g,'&Ecirc;'); // 202 CA
texte = texte.replace(//g,'&Euml;'); // 203 CB
texte = texte.replace(//g,'&Igrave;'); // 204 CC
texte = texte.replace(//g,'&Iacute;'); // 205 CD
texte = texte.replace(//g,'&Icirc;'); // 206 CE
texte = texte.replace(//g,'&Iuml;'); // 207 CF
texte = texte.replace(//g,'&ETH;'); // 208 D0
texte = texte.replace(//g,'&Ntilde;'); // 209 D1
texte = texte.replace(//g,'&Ograve;'); // 210 D2
texte = texte.replace(//g,'&Oacute;'); // 211 D3
texte = texte.replace(//g,'&Ocirc;'); // 212 D4
texte = texte.replace(//g,'&Otilde;'); // 213 D5
texte = texte.replace(//g,'&Ouml;'); // 214 D6
texte = texte.replace(//g,'&times;'); // 215 D7
texte = texte.replace(//g,'&Oslash;'); // 216 D8
texte = texte.replace(//g,'&Ugrave;'); // 217 D9
texte = texte.replace(//g,'&Uacute;'); // 218 DA
texte = texte.replace(//g,'&Ucirc;'); // 219 DB
texte = texte.replace(//g,'&Uuml;'); // 220 DC
texte = texte.replace(//g,'&Yacute;'); // 221 DD
texte = texte.replace(//g,'&THORN;'); // 222 DE
texte = texte.replace(//g,'&szlig;'); // 223 DF
texte = texte.replace(//g,'&aacute;'); // 224 E0
texte = texte.replace(//g,'&aacute;'); // 225 E1
texte = texte.replace(//g,'&acirc;'); // 226 E2
texte = texte.replace(//g,'&atilde;'); // 227 E3
texte = texte.replace(//g,'&auml;'); // 228 E4
texte = texte.replace(//g,'&aring;'); // 229 E5
texte = texte.replace(//g,'&aelig;'); // 230 E6
texte = texte.replace(//g,'&ccedil;'); // 231 E7
texte = texte.replace(//g,'&egrave;'); // 232 E8
texte = texte.replace(//g,'&eacute;'); // 233 E9
texte = texte.replace(//g,'&ecirc;'); // 234 EA
texte = texte.replace(//g,'&euml;'); // 235 EB
texte = texte.replace(//g,'&igrave;'); // 236 EC
texte = texte.replace(//g,'&iacute;'); // 237 ED
texte = texte.replace(//g,'&icirc;'); // 238 EE
texte = texte.replace(//g,'&iuml;'); // 239 EF
texte = texte.replace(//g,'&eth;'); // 240 F0
texte = texte.replace(//g,'&ntilde;'); // 241 F1
texte = texte.replace(//g,'&ograve;'); // 242 F2
texte = texte.replace(//g,'&oacute;'); // 243 F3
texte = texte.replace(//g,'&ocirc;'); // 244 F4
texte = texte.replace(//g,'&otilde;'); // 245 F5
texte = texte.replace(//g,'&ouml;'); // 246 F6
texte = texte.replace(//g,'&divide;'); // 247 F7
texte = texte.replace(//g,'&oslash;'); // 248 F8
texte = texte.replace(//g,'&ugrave;'); // 249 F9
texte = texte.replace(//g,'&uacute;'); // 250 FA
texte = texte.replace(//g,'&ucirc;'); // 251 FB
texte = texte.replace(//g,'&uuml;'); // 252 FC
texte = texte.replace(//g,'&yacute;'); // 253 FD
texte = texte.replace(//g,'&thorn;'); // 254 FE
texte = texte.replace(//g,'&yuml;'); // 255 FF
return texte;
}

/*FONCTION POUR QUE LE TRI DE DHTMLX NE SE FASSE PAS EN FONCTION DE LA CASSE*/
function str_custom(a,b,order){ 
	return (a.toLowerCase()>b.toLowerCase()?1:-1)*(order=="asc"?1:-1);
}
/*END*/
/*FONCTION POUR QUE LE TRI DES DATES DE DHTMLX SE FASSE DE CETTE MANIERE JOURS/MOIS/ANNEE*/
function date_custom(a,b,order){ 
	a=a.split("/")
	b=b.split("/")
	if (a[2]==b[2]){
		if (a[1]==b[1])
			return (a[0]>b[0]?1:-1)*(order=="asc"?1:-1);
		else
			return (a[1]>b[1]?1:-1)*(order=="asc"?1:-1);
	} else
		 return (a[2]>b[2]?1:-1)*(order=="asc"?1:-1);
};
/*END*/
function maxlength_textarea(id, crid, max)
{
var txtarea = document.getElementById(id);
    document.getElementById(crid).innerHTML=max-txtarea.value.length;
            txtarea.onkeypress=function(){eval('v_maxlength("'+id+'","'+crid+'",'+max+');')};
            txtarea.onblur=function(){eval('v_maxlength("'+id+'","'+crid+'",'+max+');')};
            txtarea.onkeyup=function(){eval('v_maxlength("'+id+'","'+crid+'",'+max+');')};
            txtarea.onkeydown=function(){eval('v_maxlength("'+id+'","'+crid+'",'+max+');')};
}
function v_maxlength(id, crid, max)
	{
var txtarea = document.getElementById(id);
var crreste = document.getElementById(crid);
var len = txtarea.value.length;
    if(len>max){
       txtarea.value=txtarea.value.substr(0,max);
    }
       len = txtarea.value.length;
       crreste.innerHTML=max-len;
}

function GetId(id)
{
return document.getElementById(id);
}
var i=false; // La variable i nous dit si la bulle est visible ou non
 
function move(e) {
  if(i) {  // Si la bulle est visible, on calcul en temps reel sa position ideale
    if (navigator.appName!="Microsoft Internet Explorer") { // Si on est pas sous IE
    GetId("curseur").style.left=e.pageX + -450+"px";
    GetId("curseur").style.top=e.pageY + 15+"px";
    }
    else { 
    if(document.documentElement.clientWidth>0) {
GetId("curseur").style.left=-450+event.x+document.documentElement.scrollLeft+"px";
GetId("curseur").style.top=20+event.y+document.documentElement.scrollTop+"px";
    } else {
GetId("curseur").style.left=-450+event.x+document.body.scrollLeft+"px";
GetId("curseur").style.top=20+event.y+document.body.scrollTop+"px";
         }
    }
  }
}
function montre(text) {
	var text = document.getElementById('textinfosbulle').innerHTML; 
  if(i==false) {
  GetId("curseur").style.visibility="visible"; // Si il est cacher (la verif n'est qu'une securité) on le rend visible.
  GetId("curseur").innerHTML = text; // on copie notre texte dans l'élément html
  i=true;
  }
}
function cache() {
if(i==true) {
GetId("curseur").style.visibility="hidden"; // Si la bulle est visible on la cache
i=false;
}
}
document.onmousemove=move; // dès que la souris bouge, on appelle la fonction move pour mettre   jour la position de la bulle.
<!--Fin du script d'infobulle//-->


function script_sxscbx(vform,vname) {
if (document.forms[vform.name].elements["CBX."+vname].checked)
{ document.forms[vform.name].elements["O_CALL."+vname].value="Oui" }
else { document.forms[vform.name].elements["O_CALL."+vname].value="Non" };
};


function chiffres(event) {
// Compatibilit IE / Firefox
if(!event&&window.event) {
event=window.event;
}
// IE
if(event.keyCode < 48 || event.keyCode > 57)  {
			if (event.keyCode == 8)
            return;

event.returnValue = false;
event.cancelBubble = true;
}
// DOM
if(event.which < 48 || event.which > 57) {
			if (event.which == 8)
            return;

event.preventDefault();
event.stopPropagation();
}
}

function onlyNumericAndComma(event) {
	
	
	// Compatibilit IE / Firefox
	if (!event&&window.event) {
		event=window.event;
	}
	
	// IE
	if ((event.keyCode >= 48 && event.keyCode <= 57) || event.keyCode == 8 || event.keyCode == 46 )  {
 
 		event.returnValue = true;
		event.cancelBubble = false;
	}
	else {
	   event.returnValue=false;
	   event.cancelBubble = true;
	}

	// DOM
	if ((event.which >= 48 && event.which <= 57) || event.which == 8 || event.which == 46 )  {
      return;
	}
	else {
		event.preventDefault();
		event.stopPropagation();
		
	}
	
}
function onlyNumericAndplusAndspace(event) {
	
	
	// Compatibilit IE / Firefox
	if (!event&&window.event) {
		event=window.event;
	}
	
	// IE
	if ((event.keyCode >= 48 && event.keyCode <= 57) || event.keyCode == 8 || event.keyCode == 43 || event.keyCode == 32 || event.keyCode == 40 || event.keyCode == 41 )  {
 
 		event.returnValue = true;
		event.cancelBubble = false;
	}
	else {
	   event.returnValue=false;
	   event.cancelBubble = true;
	}

	// DOM
	if ((event.which >= 48 && event.which <= 57) || event.which == 8 || event.which == 43 || event.which == 32 || event.which == 40 || event.which == 41 )  {
      return;
	}
	else {
		event.preventDefault();
		event.stopPropagation();
		
	}
	
}
//function check()
//{
//reg = new RegExp('[^0-9]+', 'g');
//valeur = document.getElementById('ACCESSLEVEL').editsupp.value;
//if(reg.test(valeur))
//{
//document.getElementById('ACCESSLEVEL').editsupp.value=document.getElementById('ACCESSLEVEL').editsupp.value.replace(/[^0-9]+/, '');
//}
//else
//{
//
//return true;
//}
//}

(function() { 
 
    // Fonction d'ajout de gestionnaire d'vnements non intrusifs 
    var _addEvent = function(oEl, sEvType, fn, bCapture) { 
        return document.addEventListener ? 
            oEl.addEventListener(sEvType, fn, bCapture || false): 
            oEl.attachEvent ? 
                oEl.attachEvent('on' + sEvType, fn): 
                false; 
    }; 
 
    // Ajout d'une classe sur l'lment html afin de disposer des styles initiaux lorsque Javascript est disponible 
    document.documentElement.className += ' hasJS'; 
     
    // Fonction d'affichage et masquage sous certaines conditions 
    // @param: (object) oControl -> lien pilotant l'affichage / masquage 
    // @param: (object) oTarget -> lment affich / masqu 
    // @param: (function) fTest -> Fonction dterminant si l'lment doit tre affich ou masqu 
    var _openClose = function(oControl, oTarget, fTest) { 
     
        // Si on ne dispose pas, au minimum, d'un lien pilote et d'un lment  afficher / masquer, 
        // on sort de la fonction 
        if(!(oControl && oTarget)) { 
            return; 
        } 
         
        // Fonction d'affichage 
        var _affiche = function() { 
         
            // On modifie le contenu du lien pour avoir un texte adapt  la situation 
            oControl.innerHTML = 'Masqu' + oControl.innerHTML.slice(6); 
             
            // On ajoute la classe CSS affichant l'lment cible (textarea) 
            oTarget.className += ' showComm'; 
             
            // Si la fonction _affiche n'a pas d'argument, on slectionne le contenu de l'lment cible 
            if(arguments.length == 0) { 
                oTarget.select(); 
            } 
        }; 
         
        // Si une fonction est passe en troisime paramtre d'OpenClose et si celle-ci retourne true, 
        // on affiche l'lment cible (sans slectionner son contenu) 
        if(fTest && fTest(oTarget)) { 
            _affiche(true); 
        } 
         
        // Gestionnaire d'vnement au clic sur le lien de contrle 
        var _clickHandler = function(e) { 
         
            // Si l'lment cible comporte la classe showComm (lment cible affich) 
            if(/\bshowComm\b/.test(oTarget.className)) { 
             
                // On modifie le contenu du lien pour avoir un texte adapt  la situation 
                oControl.innerHTML = 'Affich' + oControl.innerHTML.slice(5); 
                 
                // On supprime la classe CSS pour masquer l'lment cible (textarea) 
                oTarget.className = oTarget.className.replace(/\bshowComm\b/, ''); 
            } 
             
            // ou bien, on affiche l'lment cible en slectionnant son contenu 
            else { 
                _affiche(); 
            } 
             
            // On annule l'action par dfaut du lien pour viter de suivre son href 
            e.preventDefault(); 
        }; 
         
        // On ajoute le gestionnaire d'vnement au clic sur le lien de contrle 
        _addEvent(oControl, 'click', _clickHandler); 
    }; 
 
    // Fonction slectionnant le "label" ayant l'attribut "for" indiqu en paramtre 
    // @param: (string) sFor -> valeur de l'attribut "for" recherch 
    var _selectControl = function(sFor) { 
     
        // On slectionne tous les labels 
        var _aLabels = document.getElementsByTagName('label'); 
         
        // On les parcourt un par un 
        for(var _iLabel = 0, _iCount = _aLabels.length; _iLabel < _iCount; _iLabel++) { 
         
            // Si le label courant a l'attribut "for" recherch 
            if(_aLabels[_iLabel].htmlFor == sFor) { 
             
                // On lui ajoute un lien interne en modifiant le contenu initial 
                // pour expliquer le type de contrle 
                _aLabels[_iLabel].innerHTML = '<a href="#">Afficher les ' + _aLabels[_iLabel].innerHTML.toLowerCase() + '</a>'; 
                 
                // On sort de la fonction en retournant le lien de contrle ainsi cr 
                return _aLabels[_iLabel].getElementsByTagName('a')[0]; 
            } 
        } 
         
        // On sort de la fonction en retournant une valeur nulle si le label n'a pas t trouv 
        return; 
    }; 
 
    // Gestionnaire d'vnement au chargement de la page 
    var _loadHandler = function() { 
     
        // On lance la fonction d'affichage / masquage en lui passant les paramtres souhaits 
var _aTargets = ['commentaires','conclusion']; // Tableau dans lequel tu peux ajouter autant d'association label/textarea que tu veux 
var _fCondition = function(oEl) { 
    return oEl.value.length != 0; 
}; 
for(var _iTarget = 0, _iCount = _aTargets.length; _iTarget < _iCount; _iTarget++) { 
    _openClose( 
        _selectControl(_aTargets[_iTarget]), 
        document.getElementById(_aTargets[_iTarget]), 
        _fCondition 
    ); 
}   
    }; 
     
    // On ajoute le gestionnaire d'vnement au chargement de la page 
    _addEvent(window, 'load', _loadHandler); 
     
})();

function fitToText()
{
 if (this.scrollHeight>this.clientHeight)
 {
  this.style.height=(this.scrollHeight+20)+"px";
 }
 else
 {
  this.style.height="10px";
  this.style.height=(this.scrollHeight+20)+"px";
 }
}
//Rend visible le champs cause si l'etape clotur est choisi.
function RendVisible(trig){
var stepval=document.getElementById(trig).value;

	if ((stepval=="Wkf_000006482")||(stepval=="Wkf_000006479")){
		document.getElementById('fldcause').style.display='block';
		} else {
			document.getElementById('fldcause').style.display='none';
		  };
	if (stepval=="Wkf_000006479"){
		document.getElementById('notif_cloture').style.display='block';
		} else {
			document.getElementById('notif_cloture').style.display='none';
		  };
	if (stepval=="Wkf_000006474"){
		document.getElementById('notif_attenteSQ').style.display='block';
		} else {
			document.getElementById('notif_attenteSQ').style.display='none';
		  };
	if (stepval=="Wkf_000006477"){
		document.getElementById('notif_refuseSQ').style.display='block';
		} else {
			document.getElementById('notif_refuseSQ').style.display='none';
		  };
}
//Rend visible la case a coch "avertir l'assign" si un user assigned to est choisi.
function AddVisible(trig, fld)
{
var stepval=document.getElementById(trig).value;

if (stepval!="")
{document.getElementById(fld).style.visibility='visible';} else {document.getElementById(fld).style.visibility='hidden';};
}
function UnVisible(trig, fld)
{
var stepval=document.getElementById(trig).value;

if (stepval=="")
{document.getElementById(fld).style.visibility='hidden';} else {document.getElementById(fld).style.visibility='visible';};
}
 
function routeiframe(name){
	document.forms[name].action='';
	document.forms[name].submit();
}

function showwaiting(){
	document.getElementById('waiting').style.visibility="visible";
}

function donner_focus(chp)
{
document.getElementById(chp).focus();
}

function wroute(wsid)
{
var viewwin="view?template=editsupport.htm&objectname=O_CALL&key=O_CALL.SID="+wsid+"&SXSWEB.addvisible=visibility:hidden";
window.open(viewwin,'','width=1030,height=755,left=8,top=57');
};

function wroutedel(wsid)
{
var viewwin="validate_delete?template=thankyou.htm&objectname=O_CALL&objectname_update=O_CALL&key=O_CALL.SID="+wsid+"&SXSWEB.addvisible=visibility:hidden";
window.open(viewwin,'','width=1030,height=755,left=8,top=57');
};

function sxsroute(formname)
{
	//alert('ok1');
	document.forms[formname].action=document.forms[formname].route.value;
	document.forms[formname].submit();
	//alert('ok2');
};

//function openClose(id)
//{
//  if(document.getElementById)
//    var elt = document.getElementById(id);
//  else if(document.all)
//    var elt = document.all[ id];
//  else
//    return;
//
//  if (elt.style) {
//    if (elt.style.display == 'none')
//      elt.style.display = 'block';
//    else
//      elt.style.display = 'none';
//  }
//}
//
function contactrifunc(tri,page){
	document.getElementById('sxsweb.tricontac').value = tri;
	document.forms['triform'].action='view?template='+page;
	document.forms['triform'].submit();
}

function trifunc(tri,page){
	document.getElementById('sxsweb.tri').value = tri;
	document.forms['triform'].action='view?template='+page;
	document.forms['triform'].submit();
}

function switchonoff(formname,checkname,fieldname)
{
if (document.getElementById(formname)[checkname].checked==false) {document.getElementById(formname)[fieldname].style.visibility='hidden';} else {document.getElementById(formname)[fieldname].style.visibility='visible';};
};

function switchvaluecbx(formname,checkname)
{
if (document.getElementById(checkname).checked==false) 
    {
	  document.getElementById(checkname).value="0";
	  alert('0 : '+document.getElementById(checkname).value);
	} 
	else 
	{
	  document.getElementById(checkname).value="1";
	};
};

//function buildwhere(formname)
//{
//var where="";
//var op="";
//var arg=0;
//
//<!-- contrler si les appels actifs ET les appels termins sont tous deux cochs auquel cas on place un OR entre les deux arguments et on les groupe entre ()-->
//if (document.getElementById(formname).currentcalls_check.checked==true && document.getElementById(formname).closedcalls_check.checked==true) 
//{where="(rlower(O_CALL.STATUS)='active'"+" OR "+"rlower(O_CALL.STATUS)='ok')"; arg++;}
////{where="(rlower(O_CALL.STATUS)='active' OR lower(O_CALL.STATUS)='ok') OR (rlower(O_CALL.STATUS)='wait' OR (rlower(O_CALL.STATUS)='stop'"; arg++;}
//else
//
//<!-- sinon, on contrle si l'une ou l'autre des  conditions est active -->
//{	
//if (document.getElementById(formname).currentcalls_check.checked==true) {where=where+"rlower(O_CALL.STATUS)='active'"+op; arg++;};
//if (document.getElementById(formname).closedcalls_check.checked==true) {where=where+"rlower(O_CALL.STATUS)='ok'"; arg++;};
//};
//
//<!--alert(where);-->
//
//<!-- Si l'une des deux conditions ci-dessus est active, alors, on donne la valeur " AND "  op) pour le placer avant le prochain argument du where. Sinon, on "vide" l'oprateur op -->
//if (arg>0) 
//{op=" AND "}
//else {op=""};
//
//if (document.getElementById(formname).mycalls_check.checked==true) {where=where+op+"rlower(O_CALL.USER_ASSIGNEDTO)='"+document.getElementById(formname).assignedto.value.toLowerCase()+"'"; op=" AND "; arg++;};
//if (document.getElementById(formname).toprocess_check.checked==true) {where=where+op+"rlower(O_CALL.F_PROCESS)='"+document.getElementById(formname).toprocess_val.value.toLowerCase()+"'"; op=" AND "; arg++;};
//if (document.getElementById(formname).state_check.checked==true) {where=where+op+"rlower(O_CALL.STATE)='"+document.getElementById(formname).state_val.value.toLowerCase()+"'"; op=" AND "; arg++;};
//
//if (document.getElementById(formname).nature_check.checked==true  && document.getElementById(formname).nature_val.value!="") {where=where+op+"rlower(O_CALL.F_NATURE) LIKE '"+document.getElementById(formname).nature_val.value.toLowerCase()+"%'"; op=" AND "; arg++;};
//
//if (document.getElementById(formname).todocument_check.checked==true) {where=where+op+"O_CALL.F_DOCUMENTER='1'"; op=" AND "; arg++;};
//if (document.getElementById(formname).type_check.checked==true) {where=where+op+"rlower(O_CALL.F_TYPE)='"+document.getElementById(formname).type_val.value.toLowerCase()+"'"; op=" AND "; arg++;};
//if (document.getElementById(formname).impact_check.checked==true) {where=where+op+"rlower(O_CALL.F_IMPACT)='"+document.getElementById(formname).impact_val.value.toLowerCase()+"'"; op=" AND "; arg++;};
//if (document.getElementById(formname).program_check.checked==true) {where=where+op+"rlower(O_CALL.F_PROGRAM)='"+document.getElementById(formname).program_val.value.toLowerCase()+"'"; op=" AND "; arg++;};
//
//if (document.getElementById(formname).createdby_check.checked==true && document.getElementById(formname).createdby_val.value!="") {where=where+op+"rlower(O_CALL.USER_CREATEDBY)='"+document.getElementById(formname).createdby_val.value.toLowerCase()+"'"; op=" AND "; arg++;};
//if (document.getElementById(formname).forpartner_check.checked==true && document.getElementById(formname).forpartner_val.value!="") {where=where+op+"rlower(O_CALL.F_COMPANY_1)='"+document.getElementById(formname).forpartner_val.value.toLowerCase()+"'"; op=" AND "; arg++;};
//if (document.getElementById(formname).forclient_check.checked==true &&document.getElementById(formname).forclient_val.value!="") {where=where+op+"rlower(O_CALL.LNK_O_EMPLOY_1)='"+document.getElementById(formname).forclient_val.value.toLowerCase()+"'"; op=" AND "; arg++;};
//
//if (document.getElementById(formname).deadline_check.checked==true && document.getElementById(formname).deadline_val.value!="" && document.getElementById(formname).deadline_val.value!="Cliquez...") {where=where+op+"O_CALL.F_DEADLINE<='"+document.getElementById(formname).deadline_val.value+"'"; op=" AND "; arg++;};
//if (document.getElementById(formname).plannedfor_check.checked==true && document.getElementById(formname).plannedfor_val.value!="" && document.getElementById(formname).plannedfor_val.value!="Cliquez...") {where=where+op+"O_CALL.F_PLANNEDFOR<='"+document.getElementById(formname).plannedfor_val.value+"'"; op=" AND "; arg++;};
//
//<!-- S'il y a des arguments de filtrage... --> 
//if (arg>0) 
//{
//	<!-- contrler si un fulltext est galement prsent et lancer la requte en ajoutant [WHERE-] au where afin que les arguments fulltext de SEARCHFIELD soient passs au view.-->
//	if (document.getElementById(formname).searchfield_check.checked==true && document.getElementById(formname).searchfield.value!="" ) {where=where+"[WHERE-]";};
//	<!-- Ne pas oublier d'ajouter une accolade finale !-->
//	where="{where "+where+" order by O_CALL.SID desc}";
//	document.forms[formname].action=document.forms[formname].route.value; 
//	document.forms[formname].where.value=where;
//	alert("form="+formname+"  variable="+where);
//
//	document.forms[formname].submit();
//}
//<!-- Sinon, lancer la requte et laisser le form passer le searchfield au view s'il est aliment ou rinitialer le contenu de la page.-->
//else if (document.getElementById(formname).searchfield_check.checked==true && document.getElementById(formname).searchfield.value!="")
//	{
//	document.forms[formname].submit();}
//	else {document.getElementById(formname).searchfield.value="";
//	alert("Aucun argument de filtrage. La liste sera rinitialise");
//	<!-- Si aucun argument ni aucun fulltext n'est prsent dans le filtre, alors recharger la page comme initialement.-->
//	<!-- sxsroute('RouteSupportlist');-->
//	};
//};

function hidestatus()
{
	window.status='Bienvenue sur votre espace Synexsys !';
	return true;
if (document.layers)
	document.captureEvents(Event.MOUSEOVER | Event.MOUSEOUT | Event.MOUSEDOWN);
	document.onmouseover=hidestatus;
	document.onmouseout=hidestatus;
	document.onmousedown=hidestatus;
	document.onblur=hidestatus;
};

function empty_frame(framename)
{
  document.forms['EmptyIframe'].target=framename;
  document.forms['EmptyIframe'].submit();
};

function validate(){
 document.forms[0].submit();
};

function filldate(formname,fieldname)
{
var d = new Date();
var day=d.getDate();
var month=d.getMonth()+1;
var year=d.getFullYear();
var hours=d.getHours();
var minutes=d.getMinutes();
var seconds=d.getSeconds();

if (day<10) {day="0"+day};
if (month<10) {month="0"+month};
if (hours<10) {hours="0"+hours};
if (minutes<10) {minutes="0"+minutes};
if (seconds<10) {seconds="0"+seconds};

document.forms[formname].elements[fieldname].value=day+"."+month+"."+year+" "+hours+":"+minutes+":"+seconds;
};

function showclock(){
if (!document.layers&&!document.all&&!document.getElementById)
return

 var Digital=new Date();
 var hours=Digital.getHours();
 var minutes=Digital.getMinutes();
 var seconds=Digital.getSeconds();
 
 if (hours<=9)
{ hours="0"+hours};
 if (minutes<=9)
{ minutes="0"+minutes};
 if (seconds<=9)
 {seconds="0"+seconds};
//change font size here to your desire
myclock="<div id=clockstyle class=clockstyle>"+hours+":"+minutes+":"+seconds+"</div>";
if (document.layers){
document.layers.liveclock.document.write(myclock);
document.layers.liveclock.document.close();
}
else if (document.all)
{liveclock.innerHTML=myclock;}
else if (document.getElementById)
{document.getElementById("liveclock").innerHTML=myclock;};
setTimeout("showclock()",1000);
}

function mailtosxs(sid)
{
 mail_string = "mailto:info@dataconcept.ch?subject="+sid;
 mail_string += "&body=Vous pouvez acc&eacute;der &agrave; ce site en cliquant sur : " + location.href; 
 location.href = mail_string; 
}

function classmover(changewhat)
{
	if (document.getElementById(changewhat).className!="tabactive") 
	{document.getElementById(changewhat).className="tabover";};
};

function classmout(changewhat)
{
	if (document.getElementById(changewhat).className!="tabactive") 
	{document.getElementById(changewhat).className="tabinactive";};
};
function rout(vrout,vobj,vkey,vtemplate,vopt)
{
    if (vobj=="") 
	{
      if (vkey=="")
	  {
    	document.forms[0].action=vrout+"?template="+vtemplate+vopt;
        document.forms[0].submit();
	  }
	  else
	  {
    	document.forms[0].action=vrout+"?key="+vkey+"&template="+vtemplate+vopt;
        document.forms[0].submit();
	  };
	}
	else
	{
      if (vkey=="")
	  {
    	document.forms[0].action=vrout+"?objectname="+vobj+"&template="+vtemplate+vopt;
        document.forms[0].submit();
	  }
	  else
      {
		//alert(vrout+"?objectname="+vobj+"&key="+vkey+"&template="+vtemplate+vopt);
        document.forms[0].action=vrout+"?objectname="+vobj+"&key="+vkey+"&template="+vtemplate+vopt;
        document.forms[0].submit();
	  };
	};
};
function rout_top(vrout,vobj,vkey,vtemplate,vopt)
{
    document.forms[0].target='_top';
    if (vobj=="") 
	{
      if (vkey=="")
	  {
    	document.forms[0].action=vrout+"?template="+vtemplate+vopt;
        document.forms[0].submit();
	  }
	  else
	  {
    	document.forms[0].action=vrout+"?key="+vkey+"&template="+vtemplate+vopt;
        document.forms[0].submit();
	  };
	}
	else
	{
      if (vkey=="")
	  {
    	document.forms[0].action=vrout+"?objectname="+vobj+"&template="+vtemplate+vopt;
        document.forms[0].submit();
	  }
	  else
      { 
	  	//alert(vrout+"?objectname="+vobj+"&key="+vkey+"&template="+vtemplate+vopt);
        document.forms[0].action=vrout+"?objectname="+vobj+"&key="+vkey+"&template="+vtemplate+vopt;
        document.forms[0].submit();
	  };
	};
};
